@@ -1,20 +1,20 @@
 /*
- *  Copyright © 2017-2022 Wellington Wallace
+ *  Copyright © 2017-2023 Wellington Wallace
  *
- *  This file is part of EasyEffects.
+ *  This file is part of Easy Effects.
  *
- *  EasyEffects is free software: you can redistribute it and/or modify
+ *  Easy Effects is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  EasyEffects is distributed in the hope that it will be useful,
+ *  Easy Effects is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with EasyEffects.  If not, see <https://www.gnu.org/licenses/>.
+ *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -23,6 +23,10 @@
 #include <deque>
 #include "plugin_base.hpp"
 
+#ifdef SPEEX_AVAILABLE
+#include <speex/speex_preprocess.h>
+#endif
+
 class EchoCanceller : public PluginBase {
  public:
   EchoCanceller(const std::string& tag,
@@ -54,6 +58,7 @@ class EchoCanceller : public PluginBase {
   uint blocksize_ms = 20U;
   uint filter_length_ms = 100U;
   uint latency_n_frames = 0U;
+  int residual_echo_suppression = -10;
 
   float latency_value = 0.0F;
 
@@ -71,5 +76,13 @@ class EchoCanceller : public PluginBase {
   SpeexEchoState* echo_state_L = nullptr;
   SpeexEchoState* echo_state_R = nullptr;
 
+#ifdef SPEEX_AVAILABLE
+
+  SpeexPreprocessState *state_left = nullptr, *state_right = nullptr;
+
+  void free_speex();
+
+#endif
+
   void init_speex();
 };
