@@ -1,20 +1,20 @@
 /*
- *  Copyright © 2017-2022 Wellington Wallace
+ *  Copyright © 2017-2023 Wellington Wallace
  *
- *  This file is part of EasyEffects.
+ *  This file is part of Easy Effects.
  *
- *  EasyEffects is free software: you can redistribute it and/or modify
+ *  Easy Effects is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  EasyEffects is distributed in the hope that it will be useful,
+ *  Easy Effects is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with EasyEffects.  If not, see <https://www.gnu.org/licenses/>.
+ *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "convolver_menu_impulses.hpp"
@@ -27,7 +27,7 @@ enum class ImpulseImportState { success, no_regular_file, no_frame, no_stereo };
 
 auto constexpr irs_ext = ".irs";
 
-static std::filesystem::path irs_dir = g_get_user_config_dir() + "/easyeffects/irs"s;
+std::filesystem::path irs_dir = g_get_user_config_dir() + "/easyeffects/irs"s;
 
 struct _ConvolverMenuImpulses {
   GtkBox parent_instance;
@@ -73,7 +73,9 @@ auto import_irs_file(const std::string& file_path) -> ImpulseImportState {
     util::warning(file_path + " loading failed");
 
     return ImpulseImportState::no_frame;
-  } else if (file.channels() != 2) {
+  }
+
+  if (file.channels() != 2) {
     util::warning("Only stereo impulse files are supported!");
     util::warning(file_path + " loading failed");
 
