@@ -1,20 +1,20 @@
 /*
- *  Copyright © 2017-2022 Wellington Wallace
+ *  Copyright © 2017-2023 Wellington Wallace
  *
- *  This file is part of EasyEffects.
+ *  This file is part of Easy Effects.
  *
- *  EasyEffects is free software: you can redistribute it and/or modify
+ *  Easy Effects is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  EasyEffects is distributed in the hope that it will be useful,
+ *  Easy Effects is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with EasyEffects.  If not, see <https://www.gnu.org/licenses/>.
+ *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "effects_box.hpp"
@@ -41,9 +41,7 @@ struct Data {
 
   float global_output_level_left, global_output_level_right, pipeline_latency_ms;
 
-  std::vector<float> spectrum_mag, spectrum_freqs, spectrum_x_axis;
-
-  std::vector<uint> spectrum_bin_count;
+  std::vector<double> spectrum_mag, spectrum_x_axis, spectrum_freqs;
 
   std::vector<sigc::connection> connections;
 
@@ -98,14 +96,12 @@ void init_spectrum_frequency_axis(EffectsBox* self) {
       return;
     }
 
-    self->data->spectrum_x_axis =
-        util::logspace(min_freq, max_freq, g_settings_get_int(self->settings_spectrum, "n-points"));
+    auto log_x_axis = util::logspace(min_freq, max_freq, g_settings_get_int(self->settings_spectrum, "n-points"));
 
-    const auto x_axis_size = self->data->spectrum_x_axis.size();
+    self->data->spectrum_x_axis.resize(log_x_axis.size());
+    self->data->spectrum_mag.resize(log_x_axis.size());
 
-    self->data->spectrum_mag.resize(x_axis_size);
-
-    self->data->spectrum_bin_count.resize(x_axis_size);
+    std::copy(log_x_axis.begin(), log_x_axis.end(), self->data->spectrum_x_axis.begin());
 
     ui::chart::set_x_data(self->spectrum_chart, self->data->spectrum_x_axis);
   }
@@ -310,7 +306,7 @@ void setup(EffectsBox* self, app::Application* application, PipelineType pipelin
 
   adw_view_stack_page_set_icon_name(self->plugins_box_page, "emblem-music-symbolic");
 
-  // setting up the boxes we added t other stack
+  // setting up the boxes we added to the stack
 
   ui::apps_box::setup(self->appsBox, application, pipeline_type, icon_theme);
   ui::plugins_box::setup(self->pluginsBox, application, pipeline_type);
@@ -353,7 +349,7 @@ void setup(EffectsBox* self, app::Application* application, PipelineType pipelin
   // spectrum array
 
   self->data->connections.push_back(
-      self->data->effects_base->spectrum->power.connect([=](uint rate, uint n_bands, std::vector<float> magnitudes) {
+      self->data->effects_base->spectrum->power.connect([=](uint rate, uint n_bands, std::vector<double> magnitudes) {
         if (!ui::chart::get_is_visible(self->spectrum_chart)) {
           return;
         }
@@ -369,36 +365,18 @@ void setup(EffectsBox* self, app::Application* application, PipelineType pipelin
           init_spectrum_frequency_axis(self);
         }
 
-        std::ranges::fill(self->data->spectrum_mag, 0.0F);
-        std::ranges::fill(self->data->spectrum_bin_count, 0U);
+        auto* acc = gsl_interp_accel_alloc();
+        auto* spline = gsl_spline_alloc(gsl_interp_steffen, n_bands);
 
-        // reducing the amount of data so we can plot them
+        gsl_spline_init(spline, self->data->spectrum_freqs.data(), magnitudes.data(), n_bands);
 
-        size_t last_j = 0U;
-
-        for (size_t n = 0U; n < self->data->spectrum_x_axis.size(); n++) {
-          for (size_t j = last_j; j < self->data->spectrum_freqs.size(); j++) {
-            if (self->data->spectrum_freqs[j] > self->data->spectrum_x_axis[n]) {
-              last_j = j;
-
-              break;
-            } else {
-              self->data->spectrum_mag[n] += magnitudes[j];
-
-              self->data->spectrum_bin_count[n]++;
-            }
-          }
+        for (size_t n = 0; n < self->data->spectrum_x_axis.size(); n++) {
+          self->data->spectrum_mag[n] =
+              static_cast<float>(gsl_spline_eval(spline, self->data->spectrum_x_axis[n], acc));
         }
 
-        for (size_t n = 0U; n < self->data->spectrum_bin_count.size(); n++) {
-          if (self->data->spectrum_bin_count[n] != 0U) {
-            continue;
-          }
-
-          if (n > 0U && n < self->data->spectrum_bin_count.size() + 1U) {
-            self->data->spectrum_mag[n] = self->data->spectrum_mag[n - 1U];
-          }
-        }
+        gsl_spline_free(spline);
+        gsl_interp_accel_free(acc);
 
         std::ranges::for_each(self->data->spectrum_mag, [](auto& v) {
           v = 10.0F * std::log10(v);
@@ -415,7 +393,7 @@ void setup(EffectsBox* self, app::Application* application, PipelineType pipelin
 
   // As we are showing the window we want the filters to send notifications about level meters, etc
 
-  self->data->effects_base->spectrum->bypass = !g_settings_get_boolean(self->settings_spectrum, "show");
+  self->data->effects_base->spectrum->bypass = g_settings_get_boolean(self->settings_spectrum, "show") == 0;
 
   self->data->effects_base->output_level->set_post_messages(true);
 
