@@ -1,20 +1,20 @@
 /*
- *  Copyright © 2017-2022 Wellington Wallace
+ *  Copyright © 2017-2023 Wellington Wallace
  *
- *  This file is part of EasyEffects.
+ *  This file is part of Easy Effects.
  *
- *  EasyEffects is free software: you can redistribute it and/or modify
+ *  Easy Effects is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  EasyEffects is distributed in the hope that it will be useful,
+ *  Easy Effects is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with EasyEffects.  If not, see <https://www.gnu.org/licenses/>.
+ *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "equalizer_ui.hpp"
@@ -23,7 +23,7 @@ namespace ui::equalizer_box {
 
 using namespace tags::equalizer;
 
-constexpr int max_bands = 32U;
+constexpr uint max_bands = 32U;
 
 enum Channel { left, right };
 
@@ -34,6 +34,11 @@ struct APO_Band {
   float quality = (1.0F / std::numbers::sqrt2_v<float>);
 };
 
+struct GraphicEQ_Band {
+  float freq = 1000.0F;
+  float gain = 0.0F;
+};
+
 std::unordered_map<std::string, std::string> const FilterTypeMap = {
     {"PK", "Bell"},          {"MODAL", "Bell"},  {"PEQ", "Bell"},     {"LP", "Lo-pass"},      {"LPQ", "Lo-pass"},
     {"HP", "Hi-pass"},       {"HPQ", "Hi-pass"}, {"LS", "Lo-shelf"},  {"LSC", "Lo-shelf"},    {"LS 6DB", "Lo-shelf"},
@@ -90,10 +95,10 @@ void on_reset(EqualizerBox* self, GtkButton* btn) {
 }
 
 void on_flat_response(EqualizerBox* self, GtkButton* btn) {
-  for (int n = 0; n < max_bands; n++) {
-    g_settings_reset(self->settings_left, band_gain[n]);
+  for (uint n = 0U; n < max_bands; n++) {
+    g_settings_reset(self->settings_left, band_gain[n].data());
 
-    g_settings_reset(self->settings_right, band_gain[n]);
+    g_settings_reset(self->settings_right, band_gain[n].data());
   }
 }
 
@@ -120,16 +125,18 @@ void on_calculate_frequencies(EqualizerBox* self, GtkButton* btn) {
 
     // std::cout << n << "\t" << freq << "\t" << width << std::endl;
 
-    g_settings_set_double(self->settings_left, band_frequency[n], freq);
-    g_settings_set_double(self->settings_left, band_q[n], q);
+    g_settings_set_double(self->settings_left, band_frequency[n].data(), freq);
+    g_settings_set_double(self->settings_left, band_q[n].data(), q);
 
-    g_settings_set_double(self->settings_right, band_frequency[n], freq);
-    g_settings_set_double(self->settings_right, band_q[n], q);
+    g_settings_set_double(self->settings_right, band_frequency[n].data(), freq);
+    g_settings_set_double(self->settings_right, band_q[n].data(), q);
 
     freq0 = freq1;
   }
 }
 
+// ### APO Preset Section ###
+
 auto parse_apo_preamp(const std::string& line, double& preamp) -> bool {
   std::smatch matches;
 
@@ -286,8 +293,12 @@ auto import_apo_preset(EqualizerBox* self, const std::string& file_path) -> bool
   std::vector<struct APO_Band> bands;
   double preamp = 0.0;
 
-  if (eq_file.is_open()) {
+  if (const auto re = std::regex(R"(^[ \t]*+#)"); eq_file.is_open()) {
     for (std::string line; getline(eq_file, line);) {
+      if (std::regex_search(line, re)) {  // Avoid commented lines
+        continue;
+      }
+
       if (struct APO_Band filter; parse_apo_config_line(line, filter)) {
         bands.push_back(filter);
       } else {
@@ -301,9 +312,12 @@ auto import_apo_preset(EqualizerBox* self, const std::string& file_path) -> bool
   if (bands.empty()) {
     return false;
   }
-
+  
+  std::ranges::stable_sort(bands, {}, &APO_Band::freq);
+  
   // Apply APO parameters obtained
-  g_settings_set_int(self->settings, "num-bands", static_cast<int>(bands.size()));
+  g_settings_set_int(self->settings, "num-bands",
+                     static_cast<int>(std::min(static_cast<uint>(bands.size()), max_bands)));
   g_settings_set_double(self->settings, "input-gain", preamp);
 
   std::vector<GSettings*> settings_channels;
@@ -318,25 +332,25 @@ auto import_apo_preset(EqualizerBox* self, const std::string& file_path) -> bool
     settings_channels.push_back(self->settings_right);
   }
 
-  for (int n = 0, apo_bands = static_cast<int>(bands.size()); n < max_bands; n++) {
+  for (uint n = 0U, apo_bands = bands.size(); n < max_bands; n++) {
     for (auto* channel : settings_channels) {
       if (n < apo_bands) {
-        g_settings_set_string(channel, band_type[n], bands[n].type.c_str());
-        g_settings_set_string(channel, band_mode[n], "APO (DR)");
-        g_settings_set_double(channel, band_frequency[n], bands[n].freq);
-        g_settings_set_double(channel, band_gain[n], bands[n].gain);
-        g_settings_set_double(channel, band_q[n], bands[n].quality);
+        g_settings_set_string(channel, band_type[n].data(), bands[n].type.c_str());
+        g_settings_set_string(channel, band_mode[n].data(), "APO (DR)");
+        g_settings_set_double(channel, band_frequency[n].data(), bands[n].freq);
+        g_settings_set_double(channel, band_gain[n].data(), bands[n].gain);
+        g_settings_set_double(channel, band_q[n].data(), bands[n].quality);
       } else {
-        g_settings_set_string(channel, band_type[n], "Off");
-        g_settings_reset(channel, band_mode[n]);
-        g_settings_reset(channel, band_frequency[n]);
-        g_settings_reset(channel, band_gain[n]);
-        g_settings_reset(channel, band_q[n]);
+        g_settings_set_string(channel, band_type[n].data(), "Off");
+        g_settings_reset(channel, band_mode[n].data());
+        g_settings_reset(channel, band_frequency[n].data());
+        g_settings_reset(channel, band_gain[n].data());
+        g_settings_reset(channel, band_q[n].data());
       }
 
-      g_settings_reset(channel, band_slope[n]);
-      g_settings_reset(channel, band_solo[n]);
-      g_settings_reset(channel, band_mute[n]);
+      g_settings_reset(channel, band_slope[n].data());
+      g_settings_reset(channel, band_solo[n].data());
+      g_settings_reset(channel, band_mute[n].data());
     }
   }
 
@@ -357,23 +371,24 @@ void on_import_apo_preset_clicked(EqualizerBox* self, GtkButton* btn) {
   gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), filter);
 
   g_signal_connect(dialog, "response", G_CALLBACK(+[](GtkNativeDialog* dialog, int response, EqualizerBox* self) {
-                     if (response == GTK_RESPONSE_ACCEPT) {
-                       auto* chooser = GTK_FILE_CHOOSER(dialog);
-                       auto* file = gtk_file_chooser_get_file(chooser);
-                       auto* path = g_file_get_path(file);
-
-                       if (!import_apo_preset(self, path)) {
-                         // notify error on APO preset loading
-                         ui::show_fixed_toast(
-                             self->toast_overlay,
-                             _("APO Preset Not Loaded. File Format May Be Wrong. Please Check Its Content."));
-                       }
-
-                       g_free(path);
-
-                       g_object_unref(file);
+                     if (response != GTK_RESPONSE_ACCEPT) {
+                       g_object_unref(dialog);
+                       return;
                      }
 
+                     auto* chooser = GTK_FILE_CHOOSER(dialog);
+                     auto* file = gtk_file_chooser_get_file(chooser);
+                     auto* path = g_file_get_path(file);
+
+                     if (!import_apo_preset(self, path)) {
+                       // notify error on preset loading
+                       ui::show_fixed_toast(
+                           self->toast_overlay,
+                           _("APO Preset Not Loaded. File Format May Be Wrong. Please Check Its Content."));
+                     }
+
+                     g_free(path);
+                     g_object_unref(file);
                      g_object_unref(dialog);
                    }),
                    self);
@@ -382,10 +397,203 @@ void on_import_apo_preset_clicked(EqualizerBox* self, GtkButton* btn) {
   gtk_native_dialog_show(GTK_NATIVE_DIALOG(dialog));
 }
 
+// ### End APO Preset Section ###
+
+// ### GraphicEQ Section ###
+
+auto parse_graphiceq_config(const std::string& str, std::vector<struct GraphicEQ_Band>& bands) -> bool {
+  // Reminder: C++ std::regex supports possessive quantifiers.
+  // There's no reference of <regex> library supporting it inside the documentation, but
+  // std::regex_search("aaab"s, matches, std::regex("(a*+a++b)")) returns FALSE,
+  // which means the capturing without backtracking is supported.
+
+  std::smatch full_match;
+
+  // The first parsing stage is to ensure the given string contains a
+  // substring corresponding to the GraphicEQ format reported in the documentation:
+  // https://sourceforge.net/p/equalizerapo/wiki/Configuration%20reference/#graphiceq-since-version-10
+
+  // In order to do it, the following regular expression is used:
+  static const auto re_geq =
+      std::regex(R"(graphiceq\s*:((?:\s*\d++(?:,\d++)?+(?:\.\d++)?+\s++[+-]?+\d++(?:\.\d++)?+[ \t]*+(?:;|$))++))",
+                 std::regex::icase);
+
+  // That regex is quite permissive since:
+  // - It's case insensitive;
+  // - Gain values can be signed (with leading +/-);
+  // - Frequency values can use a comma as thousand separator.
+
+  // Note that the last class does not include the newline as whitespaces to allow
+  // matching the `$` as the end of line (not needed in this case, but it will also
+  // work if the input string will be multiline in the future).
+  // This ensures the last band is captured with or without the final `;`.
+  // The regex has been tested at https://regex101.com/r/JRwf4G/1
+
+  std::regex_search(str, full_match, re_geq);
+
+  // The regex captures the full match and a group related to the sequential bands.
+  if (full_match.size() != 2U) {
+    return false;
+  }
+
+  // Save the substring with all the bands and use it to extract the values.
+  // It can't be const because it's used to store the sub-sequential strings
+  // from the match_result class with suffix(). See the following while loop.
+  auto bands_substr = full_match.str(1);
+
+  // Couldn't we extract the values in one only regex checking also the GraphicEQ format?
+  // No, there's no way. Even with Perl Compatible Regex (PCRE) checking the whole format
+  // and capturing the values will return only the last repeated group (the last band),
+  // but we need all of them.
+  std::smatch band_match;
+  static const auto re_geq_band = std::regex(R"((\d++(?:,\d++)?+(?:\.\d++)?+)\s++([+-]?+\d++(?:\.\d++)?+))");
+
+  // C++ regex does not support the global PCRE flag, so we need to repeat the search in a loop.
+  while (std::regex_search(bands_substr, band_match, re_geq_band)) {
+    // The size of the match should be 3:
+    // The full match with two additional groups (frequency and gain value).
+    if (band_match.size() != 3U) {
+      break;
+    }
+
+    struct GraphicEQ_Band band;
+
+    // Extract frequency. It could have a comma as thousands separator
+    // to be removed for the correct float conversion.
+    const auto freq_str = std::regex_replace(band_match.str(1), std::regex(","), "");
+    util::str_to_num(freq_str, band.freq);
+
+    // Extract gain.
+    const auto gain_str = band_match.str(2);
+    util::str_to_num(gain_str, band.gain);
+
+    // Push the band into the vector.
+    bands.push_back(band);
+
+    // Save the sub-sequential string, so the regex can return the match
+    // for the following band (if existing).
+    bands_substr = band_match.suffix().str();
+  }
+
+  return (bands.size() > 0U);
+}
+
+auto import_graphiceq_preset(EqualizerBox* self, const std::string& file_path) -> bool {
+  std::filesystem::path p{file_path};
+
+  if (!std::filesystem::is_regular_file(p)) {
+    return false;
+  }
+
+  std::ifstream eq_file;
+  eq_file.open(p.c_str());
+
+  std::vector<struct GraphicEQ_Band> bands;
+
+  if (const auto re = std::regex(R"(^[ \t]*+#)"); eq_file.is_open()) {
+    for (std::string line; getline(eq_file, line);) {
+      if (std::regex_search(line, re)) {  // Avoid commented lines
+        continue;
+      }
+      if (parse_graphiceq_config(line, bands)) {
+        break;
+      }
+    }
+  }
+
+  eq_file.close();
+
+  if (bands.empty()) {
+    return false;
+  }
+  
+  std::ranges::stable_sort(bands, {}, &GraphicEQ_Band::freq);
+
+  // Apply GraphicEQ parameters obtained
+  g_settings_set_int(self->settings, "num-bands",
+                     static_cast<int>(std::min(static_cast<uint>(bands.size()), max_bands)));
+
+  std::vector<GSettings*> settings_channels;
+
+  // Whether to apply the parameters to both channels or the selected one only
+  if (g_settings_get_boolean(self->settings, "split-channels") == 0) {
+    settings_channels.push_back(self->settings_left);
+    settings_channels.push_back(self->settings_right);
+  } else if (g_strcmp0(gtk_stack_get_visible_child_name(self->stack), "page_left_channel") == 0) {
+    settings_channels.push_back(self->settings_left);
+  } else {
+    settings_channels.push_back(self->settings_right);
+  }
+
+  for (uint n = 0U, geq_bands = bands.size(); n < max_bands; n++) {
+    for (auto* channel : settings_channels) {
+      if (n < geq_bands) {
+        g_settings_set_string(channel, band_type[n].data(), "Bell");
+        g_settings_set_double(channel, band_frequency[n].data(), bands[n].freq);
+        g_settings_set_double(channel, band_gain[n].data(), bands[n].gain);
+      } else {
+        g_settings_set_string(channel, band_type[n].data(), "Off");
+        g_settings_reset(channel, band_frequency[n].data());
+        g_settings_reset(channel, band_gain[n].data());
+      }
+
+      g_settings_reset(channel, band_mode[n].data());
+      g_settings_reset(channel, band_q[n].data());
+      g_settings_reset(channel, band_slope[n].data());
+      g_settings_reset(channel, band_solo[n].data());
+      g_settings_reset(channel, band_mute[n].data());
+    }
+  }
+
+  return true;
+}
+
+void on_import_geq_preset_clicked(EqualizerBox* self, GtkButton* btn) {
+  auto* active_window = gtk_application_get_active_window(GTK_APPLICATION(self->data->application));
+
+  auto* dialog = gtk_file_chooser_native_new(_("Import GraphicEQ Preset File"), active_window,
+                                             GTK_FILE_CHOOSER_ACTION_OPEN, _("Open"), _("Cancel"));
+
+  auto* filter = gtk_file_filter_new();
+
+  gtk_file_filter_add_pattern(filter, "*.txt");
+  gtk_file_filter_set_name(filter, _("GraphicEQ Presets"));
+
+  gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), filter);
+
+  g_signal_connect(dialog, "response", G_CALLBACK(+[](GtkNativeDialog* dialog, int response, EqualizerBox* self) {
+                     if (response != GTK_RESPONSE_ACCEPT) {
+                       g_object_unref(dialog);
+                       return;
+                     }
+
+                     auto* chooser = GTK_FILE_CHOOSER(dialog);
+                     auto* file = gtk_file_chooser_get_file(chooser);
+                     auto* path = g_file_get_path(file);
+
+                     if (!import_graphiceq_preset(self, path)) {
+                       // notify error on preset loading
+                       ui::show_fixed_toast(
+                           self->toast_overlay,
+                           _("GraphicEQ Preset Not Loaded. File Format May Be Wrong. Please Check Its Content."));
+                     }
+
+                     g_free(path);
+                     g_object_unref(file);
+                     g_object_unref(dialog);
+                   }),
+                   self);
+
+  gtk_native_dialog_set_modal(GTK_NATIVE_DIALOG(dialog), 1);
+  gtk_native_dialog_show(GTK_NATIVE_DIALOG(dialog));
+}
+
+// ### End GraphicEQ Section ###
+
 template <Channel channel>
 void build_channel_bands(EqualizerBox* self, const int& nbands, const bool& split_mode) {
-  GSettings* settings;
-  GtkBox* bands_box;
+  GSettings* settings = nullptr;
+  GtkBox* bands_box = nullptr;
 
   if constexpr (channel == Channel::left) {
     settings = self->settings_left;
@@ -398,7 +606,7 @@ void build_channel_bands(EqualizerBox* self, const int& nbands, const bool& spli
   }
 
   for (int n = 0; n < nbands; n++) {
-    auto band_box = ui::equalizer_band_box::create();
+    auto* band_box = ui::equalizer_band_box::create();
 
     ui::equalizer_band_box::setup(band_box, settings, n);
 
@@ -418,20 +626,14 @@ void build_all_bands(EqualizerBox* self) {
   self->data->gconnections_left.clear();
   self->data->gconnections_right.clear();
 
-  for (auto* child = gtk_widget_get_first_child(GTK_WIDGET(self->bands_box_left)); child != nullptr;) {
-    auto* next_child = gtk_widget_get_next_sibling(child);
+  for (auto* band_box_ptr : {self->bands_box_left, self->bands_box_right}) {
+    for (auto* child = gtk_widget_get_first_child(GTK_WIDGET(band_box_ptr)); child != nullptr;) {
+      auto* next_child = gtk_widget_get_next_sibling(child);
 
-    gtk_box_remove(self->bands_box_left, child);
+      gtk_box_remove(band_box_ptr, child);
 
-    child = next_child;
-  }
-
-  for (auto* child = gtk_widget_get_first_child(GTK_WIDGET(self->bands_box_right)); child != nullptr;) {
-    auto* next_child = gtk_widget_get_next_sibling(child);
-
-    gtk_box_remove(self->bands_box_right, child);
-
-    child = next_child;
+      child = next_child;
+    }
   }
 
   const auto split = g_settings_get_boolean(self->settings, "split-channels") != 0;
@@ -609,6 +811,7 @@ void equalizer_box_class_init(EqualizerBoxClass* klass) {
   gtk_widget_class_bind_template_callback(widget_class, on_flat_response);
   gtk_widget_class_bind_template_callback(widget_class, on_calculate_frequencies);
   gtk_widget_class_bind_template_callback(widget_class, on_import_apo_preset_clicked);
+  gtk_widget_class_bind_template_callback(widget_class, on_import_geq_preset_clicked);
 }
 
 void equalizer_box_init(EqualizerBox* self) {
