@@ -1,20 +1,20 @@
 /*
- *  Copyright © 2017-2022 Wellington Wallace
+ *  Copyright © 2017-2023 Wellington Wallace
  *
- *  This file is part of EasyEffects.
+ *  This file is part of Easy Effects.
  *
- *  EasyEffects is free software: you can redistribute it and/or modify
+ *  Easy Effects is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  EasyEffects is distributed in the hope that it will be useful,
+ *  Easy Effects is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with EasyEffects.  If not, see <https://www.gnu.org/licenses/>.
+ *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "gate_ui.hpp"
@@ -75,7 +75,7 @@ void on_reset(GateBox* self, GtkButton* btn) {
   util::reset_all_keys_except(self->settings);
 }
 
-gboolean set_dropdown_sensitive(GateBox* self, const char* active_id) {
+auto set_dropdown_sensitive(GateBox* self, const char* active_id) -> gboolean {
   if (g_strcmp0(active_id, "External") == 0) {
     return 1;
   }
@@ -124,8 +124,9 @@ void setup(GateBox* self, std::shared_ptr<Gate> gate, const std::string& schema_
     }
 
     if (node.media_class == tags::pipewire::media_class::source ||
-        node.media_class == tags::pipewire::media_class::virtual_source) {
-      auto holder = ui::holders::create(node);
+        node.media_class == tags::pipewire::media_class::virtual_source ||
+        node.media_role == tags::pipewire::media_role::dsp) {
+      auto* holder = ui::holders::create(node);
 
       g_list_store_append(self->input_devices_model, holder);
 
@@ -300,7 +301,7 @@ void setup(GateBox* self, std::shared_ptr<Gate> gate, const std::string& schema_
       g_object_unref(holder);
     }
 
-    auto holder = ui::holders::create(info);
+    auto* holder = ui::holders::create(info);
 
     g_list_store_append(self->input_devices_model, holder);
 
