@@ -1,20 +1,20 @@
 /*
- *  Copyright © 2017-2022 Wellington Wallace
+ *  Copyright © 2017-2023 Wellington Wallace
  *
- *  This file is part of EasyEffects.
+ *  This file is part of Easy Effects.
  *
- *  EasyEffects is free software: you can redistribute it and/or modify
+ *  Easy Effects is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  EasyEffects is distributed in the hope that it will be useful,
+ *  Easy Effects is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with EasyEffects.  If not, see <https://www.gnu.org/licenses/>.
+ *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "pipe_manager.hpp"
@@ -369,7 +369,7 @@ void on_node_info(void* object, const struct pw_node_info* info) {
 
     int rate = 1;
 
-    if (util::str_to_num(str.substr(delimiter_pos + 1), rate)) {
+    if (util::str_to_num(str.substr(delimiter_pos + 1U), rate)) {
       if (rate != nd->nd_info->rate) {
         nd->nd_info->rate = rate;
 
@@ -379,7 +379,7 @@ void on_node_info(void* object, const struct pw_node_info* info) {
 
     float pw_lat = 0.0F;
 
-    if (util::str_to_num(str.substr(0, delimiter_pos), pw_lat)) {
+    if (util::str_to_num(str.substr(0U, delimiter_pos), pw_lat)) {
       if (auto latency = (pw_lat / static_cast<float>(nd->nd_info->rate)); latency != nd->nd_info->latency) {
         nd->nd_info->latency = latency;
 
@@ -509,7 +509,7 @@ void on_node_event_param(void* object,
             if (type_info.name != nullptr) {
               std::string long_name = type_info.name;
 
-              format_str = long_name.substr(long_name.rfind(':') + 1);
+              format_str = long_name.substr(long_name.rfind(':') + 1U);
             }
           }
         }
@@ -774,10 +774,14 @@ void on_device_info(void* object, const struct pw_device_info* info) {
 
     spa_dict_get_string(info->props, PW_KEY_DEVICE_API, device.api);
 
-    spa_dict_get_string(info->props, SPA_KEY_DEVICE_BUS_ID, device.bus_id);
+    if (spa_dict_get_string(info->props, SPA_KEY_DEVICE_BUS_ID, device.bus_id)) {
+      std::ranges::replace(device.bus_id, ':', '_');
+      std::ranges::replace(device.bus_id, '+', '_');
+    }
 
     if (spa_dict_get_string(info->props, PW_KEY_DEVICE_BUS_PATH, device.bus_path)) {
-      std::replace(device.bus_path.begin(), device.bus_path.end(), ':', '_');
+      std::ranges::replace(device.bus_path, ':', '_');
+      std::ranges::replace(device.bus_path, '+', '_');
     }
 
     /*
@@ -1009,6 +1013,8 @@ void on_registry_global(void* data,
   auto* const pm = static_cast<PipeManager*>(data);
 
   if (g_strcmp0(type, PW_TYPE_INTERFACE_Node) == 0) {
+    bool is_ee_filter = false;
+
     if (const auto* key_media_role = spa_dict_lookup(props, PW_KEY_MEDIA_ROLE)) {
       // Exclude blocklisted media roles
 
@@ -1019,14 +1025,10 @@ void on_registry_global(void* data,
       if (g_strcmp0(key_media_role, "DSP") == 0) {
         if (const auto* key_media_category = spa_dict_lookup(props, PW_KEY_MEDIA_CATEGORY)) {
           if (g_strcmp0(key_media_category, "Filter") == 0) {
-            if (const auto* key_node_description = spa_dict_lookup(props, PW_KEY_NODE_DESCRIPTION)) {
-              std::string description(key_node_description);
-
-              if (description.length() > 3) {
-                if (description.substr(0, 2) == "ee_") {
-                  std::string node_name = spa_dict_lookup(props, PW_KEY_NODE_NAME);
-
-                  util::debug("Filter " + node_name + " with id " + util::to_string(id) + " has been added");
+            if (const auto* key_node_name = spa_dict_lookup(props, PW_KEY_NODE_NAME)) {
+              if (std::string node_name(key_node_name); node_name.size() > 3U) {
+                if (node_name.starts_with("ee_")) {
+                  is_ee_filter = true;
                 }
               }
             }
@@ -1035,117 +1037,132 @@ void on_registry_global(void* data,
       }
     }
 
+    std::string media_class;
+    std::string media_role;
+
     if (const auto* key_media_class = spa_dict_lookup(props, PW_KEY_MEDIA_CLASS)) {
-      const std::string media_class = key_media_class;
+      media_class = key_media_class;
+    }
 
-      constexpr auto class_array =
-          std::to_array({tags::pipewire::media_class::output_stream, tags::pipewire::media_class::input_stream,
-                         tags::pipewire::media_class::sink, tags::pipewire::media_class::source,
-                         tags::pipewire::media_class::virtual_source});
+    if (const auto* key_media_role = spa_dict_lookup(props, PW_KEY_MEDIA_ROLE)) {
+      media_role = key_media_role;
+    }
 
-      if (!std::any_of(class_array.begin(), class_array.end(), [&](const auto& str) { return str == media_class; })) {
-        return;
-      }
+    constexpr auto class_array =
+        std::to_array({tags::pipewire::media_class::output_stream, tags::pipewire::media_class::input_stream,
+                       tags::pipewire::media_class::sink, tags::pipewire::media_class::source,
+                       tags::pipewire::media_class::virtual_source});
 
-      std::string node_name;
+    if (!is_ee_filter &&
+        !std::any_of(class_array.begin(), class_array.end(), [&](const auto& str) { return str == media_class; })) {
+      return;
+    }
 
-      if (!spa_dict_get_string(props, PW_KEY_NODE_NAME, node_name)) {
-        return;
-      }
+    std::string node_name;
 
-      if (node_name.empty()) {
-        return;
-      }
+    if (!spa_dict_get_string(props, PW_KEY_NODE_NAME, node_name)) {
+      return;
+    }
 
-      // Exclude blocklisted node names
+    // At least for now I do not think there is a point in showing the spectrum adn the output level filters in menus
 
-      if (std::ranges::find(PipeManager::blocklist_node_name, node_name) != PipeManager::blocklist_node_name.end()) {
-        return;
-      }
+    if (node_name.empty() || util::str_contains(node_name, "output_level") ||
+        util::str_contains(node_name, "spectrum")) {
+      return;
+    }
 
-      uint64_t serial = 0U;
+    // Exclude blocklisted node names
 
-      if (!spa_dict_get_num(props, PW_KEY_OBJECT_SERIAL, serial)) {
-        util::warning(
-            "An error occurred while retrieving the object serial. The node cannot be handled by EasyEffects.");
-        return;
-      }
+    if (std::ranges::find(PipeManager::blocklist_node_name, node_name) != PipeManager::blocklist_node_name.end()) {
+      return;
+    }
 
-      // New node can be added into the node map
+    uint64_t serial = 0U;
 
-      auto* proxy =
-          static_cast<pw_proxy*>(pw_registry_bind(pm->registry, id, type, PW_VERSION_NODE, sizeof(node_data)));
+    if (!spa_dict_get_num(props, PW_KEY_OBJECT_SERIAL, serial)) {
+      util::warning(
+          "An error occurred while retrieving the object serial. The node cannot be handled by Easy Effects.");
+      return;
+    }
 
-      auto* nd = static_cast<node_data*>(pw_proxy_get_user_data(proxy));
+    // New node can be added into the node map
 
-      nd->proxy = proxy;
-      nd->pm = pm;
+    auto* proxy = static_cast<pw_proxy*>(pw_registry_bind(pm->registry, id, type, PW_VERSION_NODE, sizeof(node_data)));
 
-      nd->nd_info = new NodeInfo();
+    auto* nd = static_cast<node_data*>(pw_proxy_get_user_data(proxy));
 
-      nd->nd_info->proxy = proxy;
-      nd->nd_info->serial = serial;
-      nd->nd_info->id = id;
-      nd->nd_info->media_class = media_class;
-      nd->nd_info->name = node_name;
+    nd->proxy = proxy;
+    nd->pm = pm;
 
-      spa_dict_get_string(props, PW_KEY_NODE_DESCRIPTION, nd->nd_info->description);
+    nd->nd_info = new NodeInfo();
 
-      spa_dict_get_num(props, PW_KEY_PRIORITY_SESSION, nd->nd_info->priority);
+    nd->nd_info->proxy = proxy;
+    nd->nd_info->serial = serial;
+    nd->nd_info->id = id;
+    nd->nd_info->media_class = media_class;
+    nd->nd_info->media_role = media_role;
+    nd->nd_info->name = node_name;
 
-      spa_dict_get_num(props, PW_KEY_DEVICE_ID, nd->nd_info->device_id);
+    spa_dict_get_string(props, PW_KEY_NODE_DESCRIPTION, nd->nd_info->description);
 
-      const auto [node_it, success] = pm->node_map.insert({serial, *nd->nd_info});
+    spa_dict_get_num(props, PW_KEY_PRIORITY_SESSION, nd->nd_info->priority);
 
-      if (!success) {
-        util::warning("Cannot insert node " + util::to_string(id) + " " + node_name +
-                      " into the node map because there's already an existing serial " + util::to_string(serial));
+    spa_dict_get_num(props, PW_KEY_DEVICE_ID, nd->nd_info->device_id);
 
-        return;
-      }
+    const auto [node_it, success] = pm->node_map.insert({serial, *nd->nd_info});
 
-      pw_node_add_listener(proxy, &nd->object_listener, &node_events, nd);
-      pw_proxy_add_listener(proxy, &nd->proxy_listener, &node_proxy_events, nd);
+    if (!success) {
+      util::warning("Cannot insert node " + util::to_string(id) + " " + node_name +
+                    " into the node map because there's already an existing serial " + util::to_string(serial));
 
-      // sometimes PipeWire destroys the pointer before signal_idle is called,
-      // therefore we make a copy of NodeInfo
+      return;
+    }
 
-      const auto nd_info_copy = *nd->nd_info;
+    pw_node_add_listener(proxy, &nd->object_listener, &node_events, nd);
+    pw_proxy_add_listener(proxy, &nd->proxy_listener, &node_proxy_events, nd);
 
-      if (media_class == tags::pipewire::media_class::source && node_name != tags::pipewire::ee_source_name) {
-        util::idle_add([pm, nd_info_copy] {
-          if (PipeManager::exiting) {
-            return;
-          }
+    // sometimes PipeWire destroys the pointer before signal_idle is called,
+    // therefore we make a copy of NodeInfo
 
-          pm->source_added.emit(nd_info_copy);
-        });
-      } else if (media_class == tags::pipewire::media_class::sink && node_name != tags::pipewire::ee_sink_name) {
-        util::idle_add([pm, nd_info_copy] {
-          if (PipeManager::exiting) {
-            return;
-          }
+    const auto nd_info_copy = *nd->nd_info;
 
-          pm->sink_added.emit(nd_info_copy);
-        });
-      } else if (media_class == tags::pipewire::media_class::output_stream) {
-        util::idle_add([pm, nd_info_copy] {
-          if (PipeManager::exiting) {
-            return;
-          }
+    if (media_class == tags::pipewire::media_class::source && node_name != tags::pipewire::ee_source_name) {
+      util::idle_add([pm, nd_info_copy] {
+        if (PipeManager::exiting) {
+          return;
+        }
 
-          pm->stream_output_added.emit(nd_info_copy);
-        });
-      } else if (media_class == tags::pipewire::media_class::input_stream) {
-        util::idle_add([pm, nd_info_copy] {
-          if (PipeManager::exiting) {
-            return;
-          }
+        pm->source_added.emit(nd_info_copy);
+      });
+    } else if (media_class == tags::pipewire::media_class::sink && node_name != tags::pipewire::ee_sink_name) {
+      util::idle_add([pm, nd_info_copy] {
+        if (PipeManager::exiting) {
+          return;
+        }
 
-          pm->stream_input_added.emit(nd_info_copy);
-        });
-      }
+        pm->sink_added.emit(nd_info_copy);
+      });
+    } else if (media_class == tags::pipewire::media_class::output_stream) {
+      util::idle_add([pm, nd_info_copy] {
+        if (PipeManager::exiting) {
+          return;
+        }
 
+        pm->stream_output_added.emit(nd_info_copy);
+      });
+    } else if (media_class == tags::pipewire::media_class::input_stream) {
+      util::idle_add([pm, nd_info_copy] {
+        if (PipeManager::exiting) {
+          return;
+        }
+
+        pm->stream_input_added.emit(nd_info_copy);
+      });
+    }
+
+    // We will have debug info about our filters later
+
+    if (!is_ee_filter) {
       util::debug(media_class + " " + util::to_string(id) + " " + nd->nd_info->name + " with serial " +
                   util::to_string(serial) + " has been added");
     }
@@ -1158,7 +1175,7 @@ void on_registry_global(void* data,
 
     if (!spa_dict_get_num(props, PW_KEY_OBJECT_SERIAL, serial)) {
       util::warning(
-          "An error occurred while retrieving the object serial. This link cannot be handled by EasyEffects.");
+          "An error occurred while retrieving the object serial. This link cannot be handled by Easy Effects.");
       return;
     }
 
@@ -1199,7 +1216,7 @@ void on_registry_global(void* data,
 
     if (!spa_dict_get_num(props, PW_KEY_OBJECT_SERIAL, serial)) {
       util::warning(
-          "An error occurred while retrieving the object serial. This port cannot be handled by EasyEffects.");
+          "An error occurred while retrieving the object serial. This port cannot be handled by Easy Effects.");
       return;
     }
 
@@ -1232,7 +1249,7 @@ void on_registry_global(void* data,
 
     if (!spa_dict_get_num(props, PW_KEY_OBJECT_SERIAL, serial)) {
       util::warning(
-          "An error occurred while retrieving the object serial. This module cannot be handled by EasyEffects.");
+          "An error occurred while retrieving the object serial. This module cannot be handled by Easy Effects.");
       return;
     }
 
@@ -1263,7 +1280,7 @@ void on_registry_global(void* data,
 
     if (!spa_dict_get_num(props, PW_KEY_OBJECT_SERIAL, serial)) {
       util::warning(
-          "An error occurred while retrieving the object serial. This client cannot be handled by EasyEffects.");
+          "An error occurred while retrieving the object serial. This client cannot be handled by Easy Effects.");
       return;
     }
 
@@ -1322,7 +1339,7 @@ void on_registry_global(void* data,
 
         if (!spa_dict_get_num(props, PW_KEY_OBJECT_SERIAL, serial)) {
           util::warning(
-              "An error occurred while converting the object serial. This device cannot be handled by EasyEffects.");
+              "An error occurred while converting the object serial. This device cannot be handled by Easy Effects.");
           return;
         }
 
@@ -1450,13 +1467,13 @@ PipeManager::PipeManager() : header_version(pw_get_headers_version()), library_v
 
   pw_core_add_listener(core, &core_listener, &core_events, this);
 
-  // loading EasyEffects sink
+  // loading Easy Effects sink
 
   pw_properties* props_sink = pw_properties_new(nullptr, nullptr);
 
   pw_properties_set(props_sink, PW_KEY_APP_ID, tags::app::id);
   pw_properties_set(props_sink, PW_KEY_NODE_NAME, tags::pipewire::ee_sink_name);
-  pw_properties_set(props_sink, PW_KEY_NODE_DESCRIPTION, "EasyEffects Sink");
+  pw_properties_set(props_sink, PW_KEY_NODE_DESCRIPTION, "Easy Effects Sink");
   pw_properties_set(props_sink, PW_KEY_NODE_VIRTUAL, "true");
   pw_properties_set(props_sink, "factory.name", "support.null-audio-sink");
   pw_properties_set(props_sink, PW_KEY_MEDIA_CLASS, tags::pipewire::media_class::sink);
@@ -1474,7 +1491,7 @@ PipeManager::PipeManager() : header_version(pw_get_headers_version()), library_v
 
   pw_properties_set(props_source, PW_KEY_APP_ID, tags::app::id);
   pw_properties_set(props_source, PW_KEY_NODE_NAME, tags::pipewire::ee_source_name);
-  pw_properties_set(props_source, PW_KEY_NODE_DESCRIPTION, "EasyEffects Source");
+  pw_properties_set(props_source, PW_KEY_NODE_DESCRIPTION, "Easy Effects Source");
   pw_properties_set(props_source, PW_KEY_NODE_VIRTUAL, "true");
   pw_properties_set(props_source, "factory.name", "support.null-audio-sink");
   pw_properties_set(props_source, PW_KEY_MEDIA_CLASS, tags::pipewire::media_class::virtual_source);
