@@ -1,20 +1,20 @@
 /*
- *  Copyright © 2017-2022 Wellington Wallace
+ *  Copyright © 2017-2023 Wellington Wallace
  *
- *  This file is part of EasyEffects.
+ *  This file is part of Easy Effects.
  *
- *  EasyEffects is free software: you can redistribute it and/or modify
+ *  Easy Effects is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  EasyEffects is distributed in the hope that it will be useful,
+ *  Easy Effects is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with EasyEffects.  If not, see <https://www.gnu.org/licenses/>.
+ *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "stereo_tools.hpp"
@@ -63,6 +63,34 @@ StereoTools::StereoTools(const std::string& tag,
 
   lv2_wrapper->bind_key_enum<"mode", "mode">(settings);
 
+  auto key_v = g_settings_get_double(settings, "dry");
+
+  dry = (key_v <= util::minimum_db_d_level) ? 0.0F : static_cast<float>(util::db_to_linear(key_v));
+
+  key_v = g_settings_get_double(settings, "wet");
+
+  wet = (key_v <= util::minimum_db_d_level) ? 0.0F : static_cast<float>(util::db_to_linear(key_v));
+
+  gconnections.push_back(g_signal_connect(
+      settings, "changed::dry", G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
+        auto self = static_cast<StereoTools*>(user_data);
+
+        auto key_v = g_settings_get_double(settings, key);
+
+        self->dry = (key_v <= util::minimum_db_d_level) ? 0.0F : static_cast<float>(util::db_to_linear(key_v));
+      }),
+      this));
+
+  gconnections.push_back(g_signal_connect(
+      settings, "changed::wet", G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
+        auto self = static_cast<StereoTools*>(user_data);
+
+        auto key_v = g_settings_get_double(settings, key);
+
+        self->wet = (key_v <= util::minimum_db_d_level) ? 0.0F : static_cast<float>(util::db_to_linear(key_v));
+      }),
+      this));
+
   setup_input_output_gain();
 }
 
@@ -104,6 +132,12 @@ void StereoTools::process(std::span<float>& left_in,
   lv2_wrapper->connect_data_ports(left_in, right_in, left_out, right_out);
   lv2_wrapper->run();
 
+  for (size_t n = 0; n < left_out.size(); n++) {
+    left_out[n] = wet * left_out[n] + dry * left_in[n];
+
+    right_out[n] = wet * right_out[n] + dry * right_in[n];
+  }
+
   if (output_gain != 1.0F) {
     apply_gain(left_out, right_out, output_gain);
   }
