@@ -1,24 +1,30 @@
 /*
- *  Copyright © 2017-2022 Wellington Wallace
+ *  Copyright © 2017-2023 Wellington Wallace
  *
- *  This file is part of EasyEffects.
+ *  This file is part of Easy Effects.
  *
- *  EasyEffects is free software: you can redistribute it and/or modify
+ *  Easy Effects is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  EasyEffects is distributed in the hope that it will be useful,
+ *  Easy Effects is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with EasyEffects.  If not, see <https://www.gnu.org/licenses/>.
+ *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "tags_plugin_name.hpp"
 
+namespace {
+
+const auto id_regex = std::regex(R"(#(\d++)$)");
+
+}
+
 namespace tags::plugin_name {
 
 auto get_translated() -> std::map<std::string, std::string> {
@@ -44,6 +50,7 @@ auto get_translated() -> std::map<std::string, std::string> {
                                                    {pitch, _("Pitch")},
                                                    {reverb, _("Reverberation")},
                                                    {rnnoise, _("Noise Reduction")},
+                                                   {speex, _("Speech Processor")},
                                                    {stereo_tools, _("Stereo Tools")}};
 
   return translated;
@@ -138,6 +145,10 @@ auto get_base_name(std::string_view name) -> std::string {
     return tags::plugin_name::rnnoise;
   }
 
+  if (name.starts_with(tags::plugin_name::speex)) {
+    return tags::plugin_name::speex;
+  }
+
   if (name.starts_with(tags::plugin_name::stereo_tools)) {
     return tags::plugin_name::stereo_tools;
   }
@@ -145,4 +156,20 @@ auto get_base_name(std::string_view name) -> std::string {
   return "";
 }
 
-}  // namespace tags::plugin_name
\ No newline at end of file
+auto get_id(const std::string& name) -> uint {
+  std::smatch matches;
+
+  std::regex_search(name, matches, id_regex);
+
+  if (matches.size() != 2) {
+    return 0;
+  }
+
+  if (uint id = 0; util::str_to_num(matches[1], id)) {
+    return id;
+  }
+
+  return 0;
+}
+
+}  // namespace tags::plugin_name
